/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#if !defined(_VIEW_H)
#define _VIEW_H

#include <Elementary.h>
#include <widget_app.h>
#include "main.h"

#define EDJ_FILE "edje/main.edj"
#define GROUP_NAME "main"

/**
 * Identifier of callbacks to be set for Widget.
 *
 * @see view_set_event_callback()
  */
typedef enum _widget_event_type {
   WIDGET_EVENT_PRESSED,   /* Touch Press Event */
   WIDGET_EVENT_RELEASED,  /* Touch Release Event */
   WIDGET_EVENT_CLICKED     /* Touch Click Event */
} widget_event_type;

/* Widget event callback function signature */
typedef void  (*widget_event_cb)(widget_instance_data_s *wid);

void view_music_set_title_layout(Evas_Object *parent, const char *part_name, const char *edj_path, const char *image_path, const char *title, void *user_data);
void view_music_set_album_art(Evas_Object *parent, const char *part_name, const char *image_path, const char *default_image_path);

void view_set_image(Evas_Object *parent, const char *part_name, const char *image_path);
void view_set_text(Evas_Object *parent, const char *part_name, const char *text);
void view_set_color(Evas_Object *parent, const char *part_name, int r, int g, int b, int a);
void view_set_color_of_circle_object(Evas_Object *parent, const char *part_name, int r, int g, int b, int a);
Evas_Object *view_create_label(Evas_Object *parent);
void view_set_label_text(Evas_Object *parent, const char *part_name, const char *text);
void view_set_label(Evas_Object *parent, const char *part_name);
Evas_Object *view_create_progressbar(Evas_Object *parent, int radius, int line_width);
void view_set_progressbar(Evas_Object *parent, const char *part_name, int radius, int line_width);
void view_set_progressbar_val(Evas_Object *parent, const char *part_name, int val);
void view_set_button(Evas_Object *parent, const char *part, const char *style, const char *image_path, const char *text, Evas_Object_Event_Cb down_cb, Evas_Object_Event_Cb up_cb, Evas_Smart_Cb clicked_cb, void *data);
Evas_Object *view_create_layout(Evas_Object *parent, const char *edj_path, const char *group_name, Eext_Event_Cb cb_function, void *user_data);
Evas_Object *view_create_layout_for_conformant(Evas_Object *parent, const char *file_name, const char *group_name, Eext_Event_Cb cb_function, void *user_data);
void view_music_widget_create(widget_context_h context, const char *edj_path);
Evas_Object *view_create_conformant_without_indicator(Evas_Object *win);
void view_create(widget_context_h context, int w, int h);
void view_destroy(void *user_data);
void view_resize(void *user_data, int w, int h);
void view_set_event_callback(Evas_Object *parent, const char *part_name, widget_event_type event_type, void *event_cb, void *user_data);

#endif
